@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## DateTime Format Relative Time - ~/lib/DateTime/Format/RelativeTime.pm
-## Version v0.1.4
+## Version v0.1.5
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2024/12/30
@@ -27,7 +27,7 @@ BEGIN
     use Locale::Unicode::Data v1.3.0;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.1.4';
+    our $VERSION = 'v0.1.5';
 };
 
 use strict;
@@ -439,7 +439,7 @@ sub format_to_parts
     my $tree = $cldr->make_inheritance_tree( $locale ) ||
         return( $self->pass_error( $cldr->error ) );
     # We set an array of possible styles to try to find the most appropriate, while putting the user preferred one first
-    my @styles = ( $cldr_style, ( grep{ $_ ne $style } qw( long short narrow ) ) );
+    my @styles = ( $cldr_style, ( grep{ $_ ne $style } qw( standard short narrow ) ) );
     # If the algorithm is set to auto, we check if we can find a relative value -1, 0 or 1 for our unit type
     # If not, we fall back to the numeric pattern
     if( $algo eq 'auto' && 
@@ -471,6 +471,7 @@ sub format_to_parts
     {
         my $count = $cldr->plural_count( abs( $num ), $locale );
         my $cldr_num = ( $num < 0 ? -1 : 1 );
+        my @best = ();
         LOCALE: foreach my $loc ( @$tree )
         {
             foreach my $this_style ( @styles )
@@ -488,16 +489,24 @@ sub format_to_parts
                     return( $self->pass_error( $cldr->error ) ) if( !defined( $ref ) && $cldr->error );
                     if( $ref && scalar( keys( %$ref ) ) )
                     {
-                        $pattern = $ref->{format_pattern};
-                        last LOCALE;
+                        # If this style matches exactly that of user preferred one, we stop here, otherwise, we add it with a score so we can take the best pick after.
+                        if( $this_style eq $cldr_style )
+                        {
+                            $pattern = $ref->{format_pattern};
+                            last LOCALE;
+                        }
+                        else
+                        {
+                            push( @best, { style => $this_style, pattern => $pattern });
+                        }
                     }
                 }
             }
         }
-        # Now, we need to check for the locale's number system
-        my $locale_ns_def = $unicode->number_systems;
-        # Possible values: native, traditional, finance
-        # foreach my $ns_type ( qw( native traditional finance ) )
+        if( !defined( $pattern ) && scalar( @best ) )
+        {
+            $pattern = $best[0];
+        }
     }
     return( $self->error( "No suitable pattern could be found. Something is wrong with the Locale::Unicode::Data database." ) ) if( !defined( $pattern ) );
 
@@ -1086,7 +1095,7 @@ For users requiring exact decimal representation beyond this precision, consider
 
 =head1 VERSION
 
-    v0.1.4
+    v0.1.5
 
 =head1 DESCRIPTION
 
